# pltwal

Package that uses the active pywal colorscheme for the standard pyplot colors.

## usage:

install using pip and then import pltwal with your other modules



This is my first public project, feel free to tell me just how wrong i did everything
